import {
  Component, ViewChild, ViewEncapsulation
} from '@angular/core';
import {
  DayService, TimelineViewsService, WeekService,
  EventSettingsModel, GroupModel, WorkHoursModel, TimeScaleModel,
  ScheduleComponent, EJ2Instance, View,
  PopupOpenEventArgs,
  DragAndDropService
} from '@syncfusion/ej2-angular-schedule';

import { MultiSelect } from '@syncfusion/ej2-dropdowns';
import { ToastComponent } from '@syncfusion/ej2-angular-notifications';

import { DateTimePicker } from '@syncfusion/ej2-calendars';

import { FormValidator } from '@syncfusion/ej2-inputs';
import { Internationalization } from '@syncfusion/ej2-base';


@Component({
  selector: 'app-root',
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.scss'],
  providers: [DayService, TimelineViewsService, WeekService, DragAndDropService],
  encapsulation: ViewEncapsulation.None,
})
export class AppComponent {
  title = 'angular8';

  @ViewChild('scheduleObj', { static: false })
  public scheduleObj: ScheduleComponent;
  public group: GroupModel = {
    resources: ['Rooms'],
  };

  public roomsDataSource: Object[] = [
    { roomName: 'Nancy', id: 1, groupId: 1, roomColor: '#df5286', designation: 'Cardioligst' },
    { roomName: 'Margaret', id: 2, groupId: 1, roomColor: '#7fa900', designation: 'Neurologist' },
    { roomName: 'Robert', id: 3, groupId: 2, roomColor: '#ea7a57', designation: 'Orthopedic Surgeon' },
    { roomName: 'Laura', id: 4, groupId: 2, roomColor: '#5978ee', designation: 'Dentist' }
  ];

  @ViewChild('calendarToast', { static: false }) toastObj: ToastComponent;
  public position: Object = { X: 'Right', Y: 'Bottom' };
  public toastContent: string;
  public toastWidth = '200px';

  public allowMultiple: Boolean = true;
  public eventSettings: EventSettingsModel;
  // public selectedDate: Date;
  public timeScale: TimeScaleModel = {
    enable: true,
    interval: 90,
    slotCount: 1,
    majorSlotTemplate: '#majorSlotTemplate',
    minorSlotTemplate: '#minorSlotTemplate'
  };
  public instance: Internationalization = new Internationalization();
  getMajorTime(date: Date): string {
    return this.instance.formatDate(date, { skeleton: 'hm' });
  }
  getMinorTime(date: Date): string {
    return this.instance.formatDate(date, { skeleton: 'ms' }).replace(':00', '');
  }

  public currentView: View = 'Day';
  public firstDayOfWeek: Number = 1;
  public workHours: WorkHoursModel = { start: '08:00', end: '18:00' };
  // public minDate: Date;
  public today: Date;
  public minDate: Date = new Date(new Date().setHours(0, 0, 0, 0));
  public selectedDate: Date = new Date(new Date().setHours(0, 0, 0, 0));

  constructor(
  ) { }

  public onPopupOpen(args: PopupOpenEventArgs): void {
    // Q6 - open the Editor with one click
    if (args.type === 'QuickInfo') {
      if ((args.target.classList.contains('e-work-cells'))) {
        const dialogObj = (args.element as any).ej2_instances[0];
        dialogObj.hide();
        const currentAction = args.target.classList.contains('e-work-cells') ? 'Add' : 'Save';
        this.scheduleObj.openEditor(args.data, currentAction);
      }
      if ((args.target.classList.contains('e-appointment'))) {
        console.log('cannot edit, view details or delete an appointment');
        args.cancel = true;
        this.toastObj.show({
          title: 'Information !',
          content: 'You cannot edit, view details or delete an appointment',
          cssClass: 'e-toast-info'
        });
      }
    }

    if (args.type === 'Editor') {
      args.duration = 90;

      // var dialog = (args.element as any).ej2_instances[0];
      // dialog.open = function () {
      //   (args.element.querySelector('.e-schedule-dialog #RoomName') as any).ej2_instances[0].refresh();
      // };

      const subjectElement: HTMLInputElement = args.element.querySelector('#Subject') as HTMLInputElement;
      subjectElement.value = (args.data as any).Subject = 'Reservation';

      // const roomElement: HTMLInputElement = args.element.querySelector('#RoomName');
      // if (!roomElement.classList.contains('e-multiselect')) {
      //   let roomObject: MultiSelect = new MultiSelect({
      //     placeholder: 'Choose a room',
      //     fields: { text: 'roomName', value: 'roomName' },
      //     dataSource: (this.roomsDataSource as any),
      //     value: <string[]>(((args.data as any).RoomName instanceof Array) ? (args.data as any).RoomName : [(args.data as any).RoomName])
      //   });
      //   roomObject.appendTo(roomElement);
      // }

      const startElement: HTMLInputElement = args.element.querySelector('#StartTime') as HTMLInputElement;
      if (!startElement.classList.contains('e-datetimepicker')) {
        new DateTimePicker({ value: new Date(startElement.value) || new Date() }, startElement);
      }

      const endElement: HTMLInputElement = args.element.querySelector('#EndTime') as HTMLInputElement;
      if (!endElement.classList.contains('e-datetimepicker')) {
        new DateTimePicker({ value: new Date(endElement.value) || new Date() }, endElement);
      }

      // validations
      const formElement: HTMLElement = <HTMLElement>args.element.querySelector('.e-schedule-form');
      const validator: FormValidator = ((formElement as EJ2Instance).ej2_instances[0] as FormValidator);
      validator.dataBind();
      validator.addRules('Name', { required: true });
      validator.addRules('Email', { required: true, email: [true] });
    }

  }


  ngOnInit(): void {
  }

}

